@@ -16,6 +16,7 @@ private:
     std::unique_ptr<impl> p_Impl;
     mutable QByteArray _cachedResult; // Cache the result to avoid multiple hash finalization calls
     mutable bool _resultCached = false;
+    QCryptographicHash::Algorithm _algo;
 
 public:
     explicit AcceleratedCryptographicHash(QCryptographicHash::Algorithm method);
@@ -23,6 +24,7 @@ public:
     void addData(const char *data, int length);
     void addData(const QByteArray &data);
     QByteArray result() const;
+    void reset();
 };
 
 #endif // ACCELERATEDCRYPTOGRAPHICHASH_H
